==========
*pyapikey*
==========

.. image:: https://img.shields.io/pypi/v/pyapikey

.. image:: https://img.shields.io/github/license/veltzer/pyapikey

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pyapikey

author: Mark Veltzer

version: 0.0.6

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2020, 2021, 2022, 2023
